@@ -1,7 +1,7 @@
 package Perinci::Object::EnvResultMulti;
 
 our $DATE = '2014-10-29'; # DATE
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.18'; # VERSION
 
 use 5.010;
 use strict;
@@ -16,14 +16,14 @@ sub new {
     bless $obj, $class;
 }
 
-sub add_response {
+sub add_result {
     my ($self, $status, $message, $extra) = @_;
     my $num_ok  = 0;
     my $num_nok = 0;
 
-    push @{ ${$self}->[3]{responses} },
+    push @{ ${$self}->[3]{results} },
         {%{ $extra // {} }, status=>$status, message=>$message};
-    for (@{ ${$self}->[3]{responses} // [] }) {
+    for (@{ ${$self}->[3]{results} // [] }) {
         if ($_->{status} =~ /\A2/) {
             $num_ok++;
         } else {
@@ -45,7 +45,7 @@ sub add_response {
 }
 
 1;
-# ABSTRACT: Represent enveloped result (multistatus response)
+# ABSTRACT: Represent enveloped result (multistatus)
 
 __END__
 
@@ -55,11 +55,11 @@ __END__
 
 =head1 NAME
 
-Perinci::Object::EnvResultMulti - Represent enveloped result (multistatus response)
+Perinci::Object::EnvResultMulti - Represent enveloped result (multistatus)
 
 =head1 VERSION
 
-This document describes version 0.17 of Perinci::Object::EnvResultMulti (from Perl distribution Perinci-Object), released on 2014-10-29.
+This document describes version 0.18 of Perinci::Object::EnvResultMulti (from Perl distribution Perinci-Object), released on 2014-10-29.
 
 =head1 SYNOPSIS
 
@@ -69,13 +69,13 @@ This document describes version 0.17 of Perinci::Object::EnvResultMulti (from Pe
  sub myfunc {
      ...
 
-     # if unspecified, the default response will be [200, "Success/no items"]
+     # if unspecified, the default status will be [200, "Success/no items"]
      my $envres = Perinci::Object::EnvResultMulti->new;
 
-     # then you can add response for each item
-     $envres->add_response(200, "OK", {item_id=>1});
-     $envres->add_response(202, "OK", {item_id=>2, note=>"blah"});
-     $envres->add_response(404, "Not found", {item_id=>3});
+     # then you can add result for each item
+     $envres->add_result(200, "OK", {item_id=>1});
+     $envres->add_result(202, "OK", {item_id=>2, note=>"blah"});
+     $envres->add_result(404, "Not found", {item_id=>3});
      ...
 
      # if you add a success status, the overall status will still be 200
@@ -87,7 +87,7 @@ This document describes version 0.17 of Perinci::Object::EnvResultMulti (from Pe
      return $envres->as_struct;
 
      # the result from the above will be: [207, "Partial success", undef,
-     # {responses => [
+     # {results => [
      #     {success=>200, message=>"OK", item_id=>1},
      #     {success=>201, message=>"OK", item_id=>2, note=>"blah"},
      #     {success=>404, message=>"Not found", item_id=>3},
@@ -97,10 +97,10 @@ This document describes version 0.17 of Perinci::Object::EnvResultMulti (from Pe
 =head1 DESCRIPTION
 
 This class is a subclass of L<Perinci::Object::EnvResult> and provide a
-convenience method when you want to use multistatus/detailed per-item responses
-(specified in L<Rinci> 1.1.63). In this case, response status can be 200, 207,
-or non-success. As you add more per-item responses, this class will set/update
-the overall response status for you.
+convenience method when you want to use multistatus/detailed per-item results
+(specified in L<Rinci> 1.1.63: C<results> result metadata property). In this
+case, response status can be 200, 207, or non-success. As you add more per-item
+results, this class will set/update the overall response status for you.
 
 =head1 METHODS
 
@@ -109,9 +109,9 @@ the overall response status for you.
 Create a new object from C<$res> enveloped result array. If C<$res> is not
 specified, the default is C<< [200, "Success/no items"] >>.
 
-=head2 $envres->add_response($status, $message, \%extra)
+=head2 $envres->add_result($status, $message, \%extra)
 
-Add an item response.
+Add an item result.
 
 =head1 SEE ALSO
 
